systemtools.ProgressIndicator
=============================

.. abjad-lineage:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator

.. autoclass:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.advance
      ~abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.message
      ~abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__enter__
      ~abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__eq__
      ~abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__exit__
      ~abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__format__
      ~abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__hash__
      ~abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__ne__
      ~abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__repr__

Bases
-----

- :py:class:`abctools.ContextManager <abjad.tools.abctools.ContextManager.ContextManager>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.message
   :noindex:

Methods
-------

.. automethod:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.advance
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__enter__
   :noindex:

.. automethod:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__eq__
   :noindex:

.. automethod:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__exit__
   :noindex:

.. automethod:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__format__
   :noindex:

.. automethod:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__hash__
   :noindex:

.. automethod:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__ne__
   :noindex:

.. automethod:: abjad.tools.systemtools.ProgressIndicator.ProgressIndicator.__repr__
   :noindex:
